@@ -5,6 +5,7 @@ import os
 import pickle
 import shutil
 import sys
+import tarfile
 import zipfile
 from abc import ABCMeta, abstractmethod
 from collections import Counter, defaultdict
@@ -102,7 +103,6 @@ class Adapter(ds.Dataset, metaclass=ABCMeta):
 
         path = Path(os.path.join(datadir, name))
         temppath = Path(os.path.join(datadir, f"temp_{name}"))
-        name_list = []
         try:
             if path.exists():
                 temppath.mkdir()
@@ -113,23 +113,30 @@ class Adapter(ds.Dataset, metaclass=ABCMeta):
                 if not path.exists():
                     path.mkdir()
             else:
-                path.mkdir()
+                os.makedirs(str(path), exist_ok=True)
             for link in urls:
                 print(f"Downloading {link}")
                 filename = wget.download(link, bar=bar_progress, out=str(path))
                 print()
-                if ".zip" not in filename:
-                    name = Path(filename).name
-                    shutil.move(filename, os.path.join(path, name))
-                else:
+
+                if ".tar.gz" in filename:
+                    with tarfile.open(filename) as tar_ref:
+                        print(f"Extracting {filename}")
+                        tar_ref.extractall(path)
+
+                elif ".zip" in filename:
                     with zipfile.ZipFile(filename, "r") as zip_ref:
                         print(f"Extracting {filename}")
                         zip_ref.extractall(path)
-                        name_list += zip_ref.namelist()
-                os.remove(filename)
+                else:
+                    raise Exception(f"{filename} is not a zip file or tarball")
+                    # name = Path(filename).name
+                    # shutil.move(filename, os.path.join(path, name))
+                    # os.remove(filename)
             shutil.rmtree(str(temppath), ignore_errors=True)
             shutil.rmtree(os.path.join(str(path), "__MACOSX"), ignore_errors=True)
         except Exception as e:
+            print("WARNING: therew was an exception: {e}")
             # now remove temppath
             if temppath.exists():
                 ###
@@ -211,6 +218,7 @@ class Adapter(ds.Dataset, metaclass=ABCMeta):
             idx_set = list((map(lambda idx: self.get_idx(idx), remaining)))
         filtered_self = self.select(idx_set)
         setattr(filtered_self, "img_to_row_map", self.img_to_row_map)
+        setattr(filtered_self, "get_metadata_counters", self.get_metadata_counters)
         setattr(filtered_self, "get", self.get)
         if is_visnlang:
             try:
